inline FPattern::LopData::LopData()
:
    d_scOrLength(0),
    d_mid(0),
    d_lhs(0)
{}

inline FPattern::LopData::~LopData()
{
    delete d_lhs;
}

inline size_t FPattern::LopData::scOrLength() const
{
    return d_scOrLength;
}

inline size_t FPattern::LopData::mid() const
{
    return d_mid;
}

inline FPattern const &FPattern::LopData::lhs() const
{
    return *d_lhs;
}
