#include "rule.ih"

Rule::Rule([[maybe_unused]] States &states, bool bol, FPattern const &pattern,
           Block const &block, RuleType type)
:
    d_pattern(pattern),
    d_block(block),
    d_bol(bol),
    d_type(type)
{}

