#ifndef INCLUDED_PREINCLUDE_H_
#define INCLUDED_PREINCLUDE_H_

//  #include "../spsemunion/spsemunion.h"

#include "../charclass/charclass.h"
#include "../interval/interval.h"
#include "../fpattern/fpattern.h"
#include "../flextypes/flextypes.h"

#endif
