//#define XERR
//#include "state.ih"
//
//State::State(State const &other)
//:
//    d_data(other.d_data),
//    d_type(other.d_type),
//    d_rule(other.d_rule)
//{
//    xerr((size_t)this % 1000 << ": CC from object " << (size_t)&other % 1000);
//}
//
