#include "generator.ih"

void Generator::tokenPath(ostream &out) const
{
    key(out);
    if (
        string const &tokenPath = d_options.tokenPath(); 
        tokenPath.empty()
    )
        out << "// no token-path defined\n";
    else
        out << "#include \"" << d_options.tokenPath() << "\"\n";
}
