//#define XERR
//#include "state.ih"
//
//State::State(State &&tmp)
//:
//    d_data(std::move(tmp.d_data)),
//    d_type(tmp.d_type),
//    d_rule(tmp.d_rule)
//{
//    xerr((size_t)this % 1000 << ": MC from object " << (size_t)&tmp % 1000);
//}
//
